==> haskell-prim-uniq-0.2-242.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-prim-uniq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prim-uniq
version:              0.2
visibility:           public
id:                   prim-uniq-0.2-LbaPoK6uoS2HizfzwVOaor
key:                  prim-uniq-0.2-LbaPoK6uoS2HizfzwVOaor
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/prim-uniq
synopsis:             Opaque unique identifiers in primitive state monads
description:
    Opaque unique identifiers in primitive state monads
    and a GADT-like type using them as witnesses of type
    equality.

category:             Data, Dependent Types
abi:                  9651990e29686bfc9ed5d0228e1415a7
exposed:              True
exposed-modules:
    Data.Unique.Prim Data.Unique.Tag Unsafe.Unique.Prim
    Unsafe.Unique.Tag

import-dirs:          /usr/lib/ghc-9.6.6/site-local/prim-uniq-0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/prim-uniq-0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/prim-uniq-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prim-uniq
hs-libraries:         HSprim-uniq-0.2-LbaPoK6uoS2HizfzwVOaor
depends:
    base-4.18.2.1 dependent-sum-0.7.2.0-HfTA5YxTWEXGwqGB9upS0D
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ

haddock-interfaces:   /usr/share/doc/haskell-prim-uniq/html/prim-uniq.haddock
haddock-html:         /usr/share/doc/haskell-prim-uniq/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prim-uniq-0.2-243-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-prim-uniq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prim-uniq
version:              0.2
visibility:           public
id:                   prim-uniq-0.2-6UDnGvWSCX6DPeCOX0tbl
key:                  prim-uniq-0.2-6UDnGvWSCX6DPeCOX0tbl
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/prim-uniq
synopsis:             Opaque unique identifiers in primitive state monads
description:
    Opaque unique identifiers in primitive state monads
    and a GADT-like type using them as witnesses of type
    equality.

category:             Data, Dependent Types
abi:                  df52c250a512afbbeec4e9b2734dfc36
exposed:              True
exposed-modules:
    Data.Unique.Prim Data.Unique.Tag Unsafe.Unique.Prim
    Unsafe.Unique.Tag

import-dirs:          /usr/lib/ghc-9.6.6/site-local/prim-uniq-0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/prim-uniq-0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/prim-uniq-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prim-uniq
hs-libraries:         HSprim-uniq-0.2-6UDnGvWSCX6DPeCOX0tbl
depends:
    base-4.18.2.1 dependent-sum-0.7.2.0-qEijTnHeq8F65XWeXqYVy
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi

haddock-interfaces:   /usr/share/doc/haskell-prim-uniq/html/prim-uniq.haddock
haddock-html:         /usr/share/doc/haskell-prim-uniq/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
